#delimit ;
set more off;
set mem 500000;
cap log close;

cd "E:\RA\NLSY\FINAL_FILES\";
log using "Logs\_hrs_stats.log", replace;


**************************************************************************
**    This file calculates summary statistics on hours worked and		**
**	  employment for all individuals.						**
** 	It calls on hrs_stats_*.do, which creates the data set used 	**
**	  to calculate all the statistics (hrs_emp.dta)				**
**************************************************************************
** Input files:  	hrs_stats_*.do							**
**												**
**												**
**												**
** Output files: 	hrs_emp.dta								**
**			various graphs							**
**												**	
**												**
**		Christine Neill, Feb 2005 (christine.neill@utoronto.ca)	**
**************************************************************************;


do "Do\hrs_stats_men.do";
save "My Statistics\hrs_emp.dta", replace;

clear;
do "Do\hrs_stats_women.do";

append using "My Statistics\hrs_emp.dta";

sort ID week;
save "My Statistics\hrs_emp.dta", replace;


** mean hours and employment variables can be summarised without need for calculating average hours by age;
** median hours should really be calculated off individual data;
** median employment has to be too;

** So summary statistics for all those with hrs observed - 
including those unemployed/out of labour force, who are all given a zero hours total **;

*  This works mostly for mean and others are just a check.  Will add median and distribution after the collapse;

**  Summary statistics for all individuals, working or not, for whom employment status is observed 
and hrs not an invalid skip (who=1);

gen INC=0;
replace INC = 1 if who==1 & SAMP<=4;
replace INC = 2 if who==1 & SAMP>4;
tabstat hrs N UN LF if INC~=0, s(n mean max min p50) c(s) by(INC); 

gen   hrgroup = 1 if hrs==0;
replace hrgroup = 2 if hrs>0 & hrs <40;
replace hrgroup = 3 if hrs==40;
replace hrgroup = 4 if hrs>40;

label define hrgv 01 "Zero" 2 "1-39" 3 "40" 4 ">40";
label values hrgroup hrgv;

sort INC;
by INC: tab hrgroup if INC~=0;


** BY AGE;

sort INC a1;
by INC a1: tabstat hrs if INC~=0, s(n mean max min p50) c(s); 
by INC a1: tab hrgroup if INC~=0;



*  BY ANY CHILDREN UNDER GIVEN AGES  (Table 6 columna);
sort ay;
by ay: tabstat hrs if INC==2, s(n mean max min p50) c(s);
* by NK under 18;
sort nku18;
by nku18: tabstat hrs if INC==2, s(n mean max min p50) c(s);

* by NK under 6;
sort nku6;
by nku6: tabstat hrs if INC==2, s(n mean max min p50) c(s);

* Women who never had children;
tabstat hrs N UN LF if INC==2 & everk==0, s(n mean max min p50) c(s) by(INC); 
tab hrgroup if INC==2 & everk==0;



** Summary statistics for those who are working and no invalid skip on hours (wwho)**;
replace INC=0;
replace INC = 1 if SAMP<=4 & wwho==1 & N==1;;
replace INC = 2 if SAMP>4 & wwho==1 & N==1;

tabstat hrs if INC~=0, s(n mean max min p50) c(s) by(INC); 

sort INC;
by INC: tab hrgroup if INC~=0;

sort INC a1;
by INC a1: tabstat hrs  if INC~=0, s(n mean max min p50) c(s); 

*  By any children under given ages;
sort ay;
by ay: tabstat hrs  if INC==2, s(n mean max min p50) c(s);


* by NK under 18;
sort nku18;
by nku18: tabstat hrs if INC==2, s(n mean max min p50) c(s);

* by NK under 6;
sort nku6;
by nku6: tabstat hrs  if INC==2, s(n mean max min p50) c(s);

* Women who never had children;
tabstat hrs  if INC==2 & everk==0, s(n mean max min p50) c(s) by(INC); 
tab hrgroup if INC==2 & everk==0;



** Summary statistics for those who are working and have non-zero hours observed (wpho) **;
replace INC=0;
replace INC = 1 if wpho==1 & SAMP<=4 & N==1;
replace INC = 2 if wpho==1 & SAMP>4 & N==1;

tabstat hrs  if INC~=0, s(n mean max min p50) c(s) by(INC); 

sort INC;
by INC: tab hrgroup if INC~=0;

sort INC a1;
by INC a1: tabstat hrs if INC~=0, s(n mean max min  p50) c(s); 

*  By any children under given ages;
sort ay;
by ay: tabstat hrs if INC==2, s(n mean max min p50) c(s);
* by NK under 18;
sort nku18;
by nku18: tabstat hrs if INC==2, s(n mean max min p50) c(s);

* by NK under 6;
sort nku6;
by nku6: tabstat hrs if INC==2, s(n mean max min p50) c(s);

* Women who never had children;
tabstat hrs if INC==2 & everk==0, s(n mean max min p50) c(s) by(INC); 
tab hrgroup if INC==2 & everk==0;


preserve;

*** Time to collapse by age so can get meaningful looks at the figures on medians.  
** First need to identify total weeks in a 'year', weeks in which hours are observed, and weeks in which the individual worked and had hours observed;
*** have chosen to give each individual one observation for the year in which he/she was a certain age;
*** Could alternatively have done it by age group;

replace hrs = 0 if hrs<0;
gen agekmin = ageyownk;

keep N UN LF who wwho wNo hrs SAMP nku6 nku18 ageyownk agekmin ID age;

collapse (sum) N UN LF who wwho wNo hrs (max) SAMP nku6 nku18 ageyownk (min) agekmin, by(ID age);
**  Summary statistics for all individuals, working or not, for whom employment status is observed and hrs not an invalid skip (who=1);
**  Relevant divisor is total weeks in the year for which hours were observed (who), or LF status observed (wNo);
** NOTE:  The kernel density estimates seem to take quite a long time and chew up memory.  Be warned!;

gen mhrs = hrs/who;
gen mN = N/wNo;
gen mUN = UN/wNo;
gen mLF = LF/wNo;

tabstat mhrs mN mUN mLF  if SAMP<=4, s(n mean max min p50) c(s); 
tabstat mhrs mN mUN mLF if SAMP>4, s(n mean max min p50) c(s); 


gen a1 = 1 if age<25;
replace a1 = 2 if age>=25 & age<30;
replace a1 = 3 if age>=30 & age<35;
replace a1 = 4 if age>=35 & age<40;
replace a1 = 5 if age>=40 & age<45;
replace a1 = 6 if age>=45;


sort a1;
by a1: tabstat mhrs mN mUN mLF if SAMP<=4, s(n mean max min  p50) c(s); 
by a1: tabstat mhrs mN mUN mLF if SAMP>4,  s(n mean max min  p50) c(s); 

local i = 1;
while `i'<=5{;

	kdensity mhrs if SAMP<=4 & a1==`i', title("KDE, mean hours worked by indiv/age, men") saving("My Statistics\graphs\_kd1HMa`i'", replace);
	kdensity mhrs if SAMP>4 & a1==`i',  title("KDE, mean hours worked by indiv/age, women") saving("My Statistics\graphs\_kd1HFa`i'", replace);

	kdensity mN if SAMP<=4 & a1==`i', title("KDE, % weeks N by age group, men")   saving("My Statistics\graphs\_kd1NMage`i'", replace);
	kdensity mN if SAMP>4 & a1==`i',  title("KDE, % weeks N by age group, women") saving("My Statistics\graphs\_kd1NFage`i'", replace);

	local i = `i'+1;
};


*  By any children under given ages;
gen ay = 8;
replace ay = 7 if agekmin<=364;
replace ay = 6 if agekmin<=312;
replace ay = 5 if agekmin<=260;
replace ay = 4 if agekmin<=52;
replace ay = 3 if agekmin<=39;
replace ay = 2 if agekmin<=26;
replace ay = 1 if agekmin<=13;

gen ay1 = 8;
replace ay1 = 7 if ageyownk<=364;
replace ay1 = 6 if ageyownk<=312;
replace ay1 = 5 if ageyownk<=260;
replace ay1 = 4 if ageyownk<=52;
replace ay1 = 3 if ageyownk<=39;
replace ay1 = 2 if ageyownk<=26;
replace ay1 = 1 if ageyownk<=13;

label var ay "Age of youngest child, minimum in year";
label var ay1 "Age of youngest child, maximum in year";

sort ay;
by ay: tabstat mhrs mN mUN mLF if SAMP>4, s(n mean max min p50) c(s);
sort ay1;
by ay1: tabstat mhrs mN mUN mLF if SAMP>4, s(n mean max min p50) c(s);


local i = 1;
while `i'<=8{;
	kdensity mhrs if SAMP>4 & ay==1, title("KDE, mean hours worked, women") saving("My Statistics\graphs\_kdhrsFak`i'", replace);
	local i = `i'+1;
};


* by NK under 18;
sort nku18;
by nku18 if SAMP>4: tabstat mhrs mN mUN mLF, s(n mean max min p50) c(s);

* by NK under 6;
sort nku6;
by nku6 if SAMP>4: tabstat mhrs mN mUN mLF, s(n mean max min p50) c(s);



** Summary statistics for those who are working and no invalid skip on hours (wwho) (obviously don't need to worry about LF status)**;

replace mhrs = hrs/wwho;


tabstat mhrs if SAMP<=4, s(n mean max min p50) c(s); 
tabstat mhrs if SAMP>4, s(n mean max min p50) c(s); 

kdensity mhrs if SAMP<=4, title("KDE, mean hours worked by indiv/age, all working men") saving("My Statistics\graphs\_kd1HoMa`i'", replace);
kdensity mhrs if SAMP>4,  title("KDE, mean hours worked by indiv/age, all working women") saving("My Statistics\graphs\_kd1HoFa`i'", replace);



sort a1;
by a1: tabstat mhrs if SAMP<=4, s(n mean max min  p50) c(s); 
by a1: tabstat mhrs if SAMP>4,  s(n mean max min  p50) c(s); 

local i = 1;
while `i'<=5{;

	kdensity mhrs if SAMP<=4 & a1==`i', title("KDE, mean hours worked by indiv/age, working men") saving("My Statistics\graphs\_kd1HoMa`i'", replace);
	kdensity mhrs if SAMP>4 & a1==`i',  title("KDE, mean hours worked by indiv/age, working women") saving("My Statistics\graphs\_kd1HoFa`i'", replace);

	local i = `i'+1;
};
*  By any children under given ages;
sort ay;
by ay: tabstat mhrs if SAMP>4, s(n mean max min p50) c(s) ;

* by NK under 18;
sort nku18;
by nku18: tabstat mhrs if SAMP>4, s(n mean max min p50) c(s);

* by NK under 6;
sort nku6;
by nku6: tabstat mhrs if SAMP>4, s(n mean max min p50) c(s);

** Summary statistics for those who are working and have non-zero hours observed (wpho) **;

replace mhrs = hrs/wpho;


tabstat mhrs if SAMP<=4, s(n mean max min p50) c(s) ; 
tabstat mhrs if SAMP>4, s(n mean max min p50) c(s); 

kdensity mhrs if SAMP<=4, title("KDE, mean hours worked by indiv/age, all working men with + hrs") saving("My Statistics\graphs\_kd1HoMa`i'", replace);
kdensity mhrs if SAMP>4,  title("KDE, mean hours worked by indiv/age, all working women with + hrs") saving("My Statistics\graphs\_kd1HoFa`i'", replace);



sort a1;
by a1: tabstat mhrs if SAMP<=4, s(n mean max min  p50) c(s); 
by a1: tabstat mhrs if SAMP>4,  s(n mean max min  p50) c(s); 

local i = 1;
while `i'<=5{;

	kdensity mhrs if SAMP<=4 & a1==`i', title("KDE, mean hours worked by indiv/age, working men with + hrs") saving("My Statistics\graphs\_kd1HpMa`i'", replace);
	kdensity mhrs if SAMP>4 & a1==`i',  title("KDE, mean hours worked by indiv/age, women with + hrs") saving("My Statistics\graphs\_kd1HpFa`i'", replace);

	local i = `i'+1;
};
*  By any children under given ages;
sort ay;
by ay: tabstat mhrs if SAMP>4, s(n mean max min p50) c(s);

* by NK under 18;
sort nku18;
by nku18: tabstat mhrs if SAMP>4, s(n mean max min p50) c(s) ;

* by NK under 6;
sort nku6;
by nku6: tabstat mhrs if SAMP>4, s(n mean max min p50) c(s);

log close;



restore;

****************************************************************
****************************************************************
This section calculates transition matrices for all individuals
for whome we observe employment status in both weeki and weekj
****************************************************************
****************************************************************;

gen F = 1 if SAMP>4;
replace F = 0 if SAMP<=4;
label define Fv 0 "Male" 1 "Female";
label values F Fv;


**  Want to get transition matrices for all individuals for whom we observe employment status in the two weeks;
sort ID week;
by ID: gen whofd = who[_n+1];

* should only do this for those for whom we observe employment status in both weeks;
cap drop INC;
gen INC = 0;
replace INC = 1 if who==1 & whofd ==1;


** Doing FT, PT, No Time here;
** Could easily change it, or could just use output and recalculate it in spreadsheet package very easily (which is what I did);

gen work = 0 if NT ==1;
gen work = 1 if FT ==1;
gen work = 2 if PT ==1;

by ID: gen workfd = work[_n+1];


tab work workfd if INC==1;
sort F;
by F: tab work workfd if INC==1;
sort ay;
by ay: tab work workfd if INC==1;
sort nku6;
by nku6: tab work workfd if INC==1;
sort nku18;
by nku18: tab work workfd if INC==1;

** NOTE:  Have defined work = part time if hours are zero despite positive employment;
** Should redo this with full time and see if it makes much difference;

log close;


