#delimit ;
set mem 500000;
set more off;
cap log close;

** Change as necessary;
cd "E:\RA\NLSY\FINAL_FILES\";



** Create and save job_matching.dta;
	do "Do\job_matching.do";


*****  Calculating hours worked for each job  ********************************;
** And reshape so observation is ID*year;

	do "rename\rename_hrsbyjob.do";
	reshape i ID;
	reshape j year;
	reshape xij HW1 HW2 HW3 HW4 HW5 HH1 HH2 HH3 HH4 HH5 J91 J92 J93 J94 J95 HW9 HH9;
	reshape xi SAMP;
	reshape long;

** IDENTIFY HOURS WORKED ON EACH JOB (INCLUDING CPS JOB = JOB 9);
** missing values coded as -999, will not show up in final figures for hrs worked by job;

mvencode HH1 HH2 HH3 HH4 HH5 HH9 HW1 HW2 HW3 HW4 HW5 HW9, mv(-999);

* creating a new variable that will contain my hours calculation for each job;
	gen HRS1 = HW1;
	gen HRS2 = HW2;
	gen HRS3 = HW3;
	gen HRS4 = HW4;
	gen HRS5 = HW5;
	gen HRS9 = HW9;


* replacing hours on job with hours including hours worked at home if the latter is greater than the former;
	replace HRS1 = HH1 if HH1>0 & HH1>HW1;
	replace HRS2 = HH2 if HH2>0 & HH2>HW2;
	replace HRS3 = HH3 if HH3>0 & HH3>HW3;
	replace HRS4 = HH4 if HH4>0 & HH4>HW4;
	replace HRS5 = HH5 if HH5>0 & HH5>HW5;
	replace HRS9 = HH9 if HH5>0 & HH5>HW5;

* replacing maximum hours for any job at 96, for consistency across years;
	replace HRS1 = 96 if HRS1>96;
	replace HRS2 = 96 if HRS2>96;
	replace HRS3 = 96 if HRS3>96;
	replace HRS4 = 96 if HRS4>96;
	replace HRS5 = 96 if HRS5>96;
	replace HRS9 = 96 if HRS9>96;

* replacing with HRS1 again for 1997 and before (since no separate hrs at home those years - just in case);
	replace HRS1 = HW1 if year<1988;
	replace HRS2 = HW2 if year<1988;
	replace HRS3 = HW3 if year<1988;
	replace HRS4 = HW4 if year<1988;
	replace HRS5 = HW5 if year<1988;
	replace HRS9 = HW9 if year<1988;


*  Replace with hours in CPS JOB if JOB X is CPS job, pre 1993;
*  (before 1993, the NLSY puts in a missing value for hours worked on job 1 if job 1 is the CPS job);
	replace HRS1 = HRS9 if year<1994 & J91==1 & year~=1979;
	replace HRS2 = HRS9 if year<1994 & J92==1 & year~=1979;
	replace HRS3 = HRS9 if year<1994 & J93==1 & year~=1979;
	replace HRS4 = HRS9 if year<1994 & J94==1 & year~=1979;
	replace HRS5 = HRS9 if year<1994 & J95==1 & year~=1979;

	replace HRS1 = HRS9 if year==1979 & J91==1 & HRS1<0 & HRS9>0;
	replace HRS2 = HRS9 if year==1979 & J92==1 & HRS2<0 & HRS9>0;
	replace HRS3 = HRS9 if year==1979 & J93==1 & HRS3<0 & HRS9>0;
	replace HRS4 = HRS9 if year==1979 & J94==1 & HRS4<0 & HRS9>0;
	replace HRS5 = HRS9 if year==1979 & J95==1 & HRS5<0 & HRS9>0;


drop HW* HH* J*;
sort ID year;

save "My Statistics\hoursbyjob.dta", replace;



** Adjusting for special cases can identify decent estimate of hours despite missing data;

replace HRS1 = 40 if ID==1440 & year==1989;
replace HRS1 = 40 if ID==2958 & year==1988;
replace HRS1 = 3 if ID==3417 & year==1979;
replace HRS1 = 40 if ID==3617 & year==1990;
replace HRS1 = 6 if ID==5188 & year==1982;
replace HRS1 = 10 if ID==12065 & year==1979;




** Need to drop any years in which individual wasn't interviewed - jobs are recorded and coded each time
	an interview is held, which means that in a year in which there was no interview, the jobs are usually those referred
	to in the next interview year.  Need to ensure I've got the right jobs matching with the job numbers;

merge (ID year) using "My Statistics\_annualfile.dta";
	tab _merge;
	drop _merge;

	drop if NI==1;
	sort ID year;

** Now matching the hours in the job with the recorded job numbers, so that I can match them to the weekly data;

	merge (ID year) using "My Statistics\job_matching.dta";
	tab _merge;
	drop _merge;

** This creates indicator variables for jobs 1-5 noting that there are missing hours despite there being a job identified;
gen IND1 = 1 if HRS1<0 & JOB1>100;
gen IND2 = 1 if HRS2<0 & JOB2>100;
gen IND3 = 1 if HRS3<0 & JOB3>100;
gen IND4 = 1 if HRS4<0 & JOB4>100;
gen IND5 = 1 if HRS5<0 & JOB5>100;

mvencode IND1 IND2 IND3 IND4 IND5, mv(0);

sum IND1 IND2 IND3 IND4 IND5;

sort ID year;
save "My Statistics\_jobfile_annual.dta", replace;

****************************************************************************************
****************************************************************************************;
** Add in information on hourly rates of pay;


infile using "Tagsets\HRP.dct", clear;
	do "rename\rename_hrp.do";
	sort ID year;


merge (ID year) using "My Statistics\_jobfile_annual.dta";
	tab _merge;
	drop _merge;
	drop HRS9;

** Merge in USCPI;
sort year;
merge (year) using "My Statistics\_USCPI.dta";
tab _merge;
drop if _merge == 2;
drop _merge;
	
drop NI weight marstat d m y age;
sort ID year;
save "My Statistics\_jobfile_annual.dta", replace;


** Turn this into a long file, with unit of observation at the ID*year*job level;

	gen ident = ID*1000+year;
	reshape clear;
	reshape i ident;
	reshape j NUMBER;
	reshape xi SAMP ID year;
	reshape xij JOB JN HRP HRS IND;
	reshape long;


	drop ident;
	mvencode JOB, mv(-100);
	keep if JOB>=100;

sort ID JOB;

save "My Statistics\_jobfile.dta", replace;




